function [ret,x0,str,ts,xts]=nonlinsim(t,x,u,flag);
%NONLINSIM	is the M-file description of the SIMULINK system named NONLINSIM.
%	The block-diagram can be displayed by typing: NONLINSIM.
%
%	SYS=NONLINSIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes NONLINSIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling NONLINSIM with a FLAG of zero:
%	[SIZES]=NONLINSIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[547,175,900,504])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0')
set_param(sys,'Stop time',     '60')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '0.05')
set_param(sys,'Relative error','1e-2')
set_param(sys,'Return vars',   '')
set_param(sys,'AssignWideVectorLines','on');

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','t',...
		'buffer','10000',...
		'position',[275,17,325,33])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[225,15,245,35])

add_block('built-in/From Workspace',[sys,'/',['engine speed',13,'[rpm]']])
set_param([sys,'/',['engine speed',13,'[rpm]']],...
		'matl_expr','[t1 nf]',...
		'position',[35,185,85,215])

add_block('built-in/To Workspace',[sys,'/','pman'])
set_param([sys,'/','pman'],...
		'mat-name','p',...
		'buffer','10000',...
		'position',[275,192,325,208])

add_block('built-in/To Workspace',[sys,'/','mat'])
set_param([sys,'/','mat'],...
		'mat-name','m',...
		'buffer','10000',...
		'position',[275,162,325,178])

add_block('built-in/To Workspace',[sys,'/','alpha'])
set_param([sys,'/','alpha'],...
		'mat-name','as',...
		'buffer','10000',...
		'position',[275,127,325,143])


%     Subsystem  ['Engine',13,'Model'].

new_system([sys,'/',['Engine',13,'Model']])
set_param([sys,'/',['Engine',13,'Model']],'Location',[398,79,1036,296])

add_block('built-in/Outport',[sys,'/',['Engine',13,'Model/Air mass flow']])
set_param([sys,'/',['Engine',13,'Model/Air mass flow']],...
		'Port','2',...
		'position',[550,65,570,85])

add_block('built-in/Outport',[sys,'/',['Engine',13,'Model/Throttle angle']])
set_param([sys,'/',['Engine',13,'Model/Throttle angle']],...
		'position',[545,10,565,30])

add_block('built-in/Integrator',[sys,'/',['Engine',13,'Model/Integrator']])
set_param([sys,'/',['Engine',13,'Model/Integrator']],...
		'hide name',0,...
		'Initial','47',...
		'position',[420,115,440,135])

add_block('built-in/Gain',[sys,'/',['Engine',13,'Model/Gain']])
set_param([sys,'/',['Engine',13,'Model/Gain']],...
		'hide name',0,...
		'Gain','84.1564/0.0065/3600',...
		'position',[360,112,385,138])

add_block('built-in/Sum',[sys,'/',['Engine',13,'Model/Sum']])
set_param([sys,'/',['Engine',13,'Model/Sum']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[320,115,340,135])

add_block('built-in/Inport',[sys,'/',['Engine',13,'Model/n']])
set_param([sys,'/',['Engine',13,'Model/n']],...
		'Port','2',...
		'position',[15,130,35,150])

add_block('built-in/Inport',[sys,'/',['Engine',13,'Model/a_s']])
set_param([sys,'/',['Engine',13,'Model/a_s']],...
		'position',[15,55,35,75])

add_block('built-in/Mux',[sys,'/',['Engine',13,'Model/Mux2']])
set_param([sys,'/',['Engine',13,'Model/Mux2']],...
		'hide name',0,...
		'inputs','2',...
		'position',[100,56,130,89])

add_block('built-in/Mux',[sys,'/',['Engine',13,'Model/Mux3']])
set_param([sys,'/',['Engine',13,'Model/Mux3']],...
		'hide name',0,...
		'inputs','2',...
		'position',[105,131,135,164])

add_block('built-in/MATLAB Fcn',[sys,'/',['Engine',13,'Model/Air flow cylinder',13,'(Function g in model)']])
set_param([sys,'/',['Engine',13,'Model/Air flow cylinder',13,'(Function g in model)']],...
		'MATLAB Fcn','gmac2',...
		'Output Width','1',...
		'position',[180,133,240,167])

add_block('built-in/MATLAB Fcn',[sys,'/',['Engine',13,'Model/Air flow through throttle',13,'(Function f in model)']])
set_param([sys,'/',['Engine',13,'Model/Air flow through throttle',13,'(Function f in model)']],...
		'MATLAB Fcn','fmat2',...
		'Output Width','1',...
		'position',[180,58,240,92])

add_block('built-in/Outport',[sys,'/',['Engine',13,'Model/Pressure']])
set_param([sys,'/',['Engine',13,'Model/Pressure']],...
		'Port','3',...
		'position',[550,115,570,135])
add_line([sys,'/',['Engine',13,'Model']],[245,75;290,75;290,120;315,120])
add_line([sys,'/',['Engine',13,'Model']],[245,150;270,150;270,130;315,130])
add_line([sys,'/',['Engine',13,'Model']],[140,150;175,150])
add_line([sys,'/',['Engine',13,'Model']],[40,140;100,140])
add_line([sys,'/',['Engine',13,'Model']],[40,65;95,65])
add_line([sys,'/',['Engine',13,'Model']],[135,75;175,75])
add_line([sys,'/',['Engine',13,'Model']],[345,125;355,125])
add_line([sys,'/',['Engine',13,'Model']],[390,125;415,125])
add_line([sys,'/',['Engine',13,'Model']],[445,125;445,35;80,35;80,80;95,80])
add_line([sys,'/',['Engine',13,'Model']],[80,80;80,155;100,155])
add_line([sys,'/',['Engine',13,'Model']],[40,65;60,65;60,20;540,20])
add_line([sys,'/',['Engine',13,'Model']],[445,125;545,125])
add_line([sys,'/',['Engine',13,'Model']],[245,75;545,75])


%     Finished composite block ['Engine',13,'Model'].

set_param([sys,'/',['Engine',13,'Model']],...
		'position',[160,150,190,190])

add_block('built-in/From Workspace',[sys,'/',['alpha motor',13,'[V]']])
set_param([sys,'/',['alpha motor',13,'[V]']],...
		'matl_expr','[t1 aef]',...
		'position',[35,125,85,155])

add_block('built-in/From Workspace',[sys,'/',['manifold pressure',13,'[kPa]']])
set_param([sys,'/',['manifold pressure',13,'[kPa]']],...
		'matl_expr','[t1 pf]',...
		'position',[35,65,85,95])

add_block('built-in/From Workspace',[sys,'/',['air mass flow',13,'[kg//h]']])
set_param([sys,'/',['air mass flow',13,'[kg//h]']],...
		'matl_expr','[t1,mf]',...
		'position',[35,10,85,40])
add_line(sys,[250,25;270,25])
add_line(sys,[90,140;115,140;115,160;155,160])
add_line(sys,[90,200;115,200;115,180;155,180])
add_line(sys,[195,155;250,155;250,135;270,135])
add_line(sys,[195,170;270,170])
add_line(sys,[195,185;250,185;250,200;270,200])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
